
<!---
FrozenIsBool True
-->

##Example

Let's build a grand child and the grand parent will point on it like a classic set,
but without a PointingSetKeyVariable for now, the path to get it is direcly the key str in the ManagementDict